import { redirect, type Actions } from '@sveltejs/kit';
import type { PageServerLoad } from './$types';
import { API_URL } from '$env/static/private';

export const load = (async ({ locals: { user } }) => {
	if (user) throw redirect(303, '/dashboard');
}) satisfies PageServerLoad;

export const actions = {
	default: async (event) => {
		const data = await event.request.formData();

		const pseudo = data.get('pseudo') as string;
		const passwd = data.get('passwd') as string;

		const res = await fetch(`${API_URL}/login`, {
			method: 'POST',
			body: JSON.stringify({
				pseudo,
				passwd
			})
		});

		if (res.ok) {
			const token = res.headers.get('Authorization')?.split(' ')[1];

			if (!token) throw new Error('No token found');

			event.cookies.set('session', token, {
				path: '/'
			});

			throw redirect(303, '/dashboard');
		}

		throw redirect(303, '/sign-in');
	}
} satisfies Actions;
